api-12 only.Expand description
Bindings to the Multimodal Input-kit API of OpenHarmony
Available with API-level 12 and newer
Official documentation: https://developer.huawei.com/consumer/cn/doc/harmonyos-references-V14/input-V14
Feature flags
OpenHarmony API level
The inputmethod API was added in API-level 12.
Defaults to no bindings at all, to maintain feature composability in ohos-sys.
Optionally enable one of the api-* features to get access to bindings for newer
OpenHarmony versions.
-
api-12— Enables bindings for OpenHarmony API-level 12. -
api-13— Enables bindings for OpenHarmony API-level 13 (No changes) -
api-14— Enables bindings for OpenHarmony API-level 14 -
api-15— Enables bindings for OpenHarmony API-level 15 -
api-16— Enables bindings for OpenHarmony API-level 16. -
api-17— Enables bindings for OpenHarmony API-level 17. -
api-18— Enables bindings for OpenHarmony API-level 18 (5.1.0). -
api-19— Enables bindings for OpenHarmony API-level 19. -
api-20— Enables bindings for OpenHarmony API-level 20. -
api-21— Enables bindings for OpenHarmony API-level 21. -
api-22— Enables bindings for OpenHarmony API-level 22.Adds the
pointer_stylemodule. -
api-23— Enables bindings for OpenHarmony API-level 23. -
document-features— Document available features when building the documentation
Modules
- axis_
type - Defines the axis event structures and enumerations.
- input_
manager - Provides functions such as event injection and status query.
- key_
code - Defines key codes of the key device.
- pointer_
style api-22