OH_Input_GetPointerStyle

Function OH_Input_GetPointerStyle 

pub unsafe extern "C" fn OH_Input_GetPointerStyle(
    windowId: i32,
    pointerStyle: *mut i32,
) -> Input_Result
Available on crate feature api-22 only.
Obtains the mouse pointer style.

Arguments

  • windowId - Window ID. The value is an integer greater than or equal to -1.

  • pointerStyle - Pointer to the pointerStyle.

Returns

  • OH_Input_GetPointerStyle function api result code [INPUT_SUCCESS] if the operation is successful; [INPUT_PARAMETER_ERROR] if parameter is a null pointer or window ID is invalid; [INPUT_SERVICE_EXCEPTION] if the service is exception.

Available since API-level: 22