OH_Input_SetPointerStyle

Function OH_Input_SetPointerStyle 

pub unsafe extern "C" fn OH_Input_SetPointerStyle(
    windowId: i32,
    pointerStyle: i32,
) -> Input_Result
Available on crate feature api-22 only.
Sets the mouse pointer style.

Arguments

  • windowId - Window ID. The value is an integer greater than or equal to 0.

  • pointerStyle - Pointer style.The value should be a member of the Input_PointerStyle enumeration.

Returns

  • OH_Input_SetPointerStyle function api result code [INPUT_SUCCESS] if the operation is successful; [INPUT_PARAMETER_ERROR] if window ID is invalid or pointerStyle is invalid; [INPUT_SERVICE_EXCEPTION] if the service is exception.

Available since API-level: 22