pub unsafe extern "C" fn OH_Input_GetCursorInfo(
cursorInfo: *mut Input_CursorInfo,
pixelmap: *mut *mut OH_PixelmapNative,
) -> Input_ResultAvailable on crate feature
api-22 only.Expand description
Retrieves cursor information. If the pixelmap parameter is specified, and the cursor is user-defined type currently, the cursor’s pixelmap will be returned along with it.
Arguments
-
cursorInfo- The object to receive the cursor info. -
pixelmap- The object to receive the cursor pixelmap, null value will be ignored.
Returns
- OH_Input_GetCursorInfo function api result code
[
INPUT_SUCCESS] if the operation is successful; [INPUT_PARAMETER_ERROR] if parameter is a null cursor; [INPUT_SERVICE_EXCEPTION] if the service is exception.
Available since API-level: 22